@@ -5,6 +5,9 @@ import re
 import Image as Pil
 import os
 import mimetypes
+import shutil
+import subprocess
+import zipfile
 
 # django
 from django.http import HttpResponse, HttpResponseNotFound, Http404
@@ -16,10 +19,12 @@ from django.template.loader import get_template
 from django.shortcuts import redirect
 from django.conf import settings
 from django.core.files.storage import default_storage
+from django.contrib import messages
 
 # local
 from tendenci.core.base.cache import IMAGE_PREVIEW_CACHE
-from tendenci.core.base.forms import PasswordForm
+from tendenci.core.base.forms import PasswordForm, AddonUploadForm
+from tendenci.core.perms.decorators import superuser_required
 from tendenci.core.theme.shortcuts import themed_response as render_to_response
 from tendenci.core.site_settings.utils import get_setting
 
@@ -311,3 +316,75 @@ def password_again(request, template_name="base/password.html"):
         'next': next,
         'form': form,
     }, context_instance=RequestContext(request))
+
+
+@superuser_required
+def addon_upload(request, template_name="base/addon_upload.html"):
+
+    form = AddonUploadForm(request.POST or None, request.FILES or None)
+    if request.method == 'POST':
+        if form.is_valid():
+            identifier = str(int(time.time()))
+            temp_file_path = 'uploads/addons/%s_%s' % (identifier, form.cleaned_data['addon'])
+            default_storage.save(temp_file_path, form.cleaned_data['addon'])
+            request.session[identifier] = temp_file_path
+            return redirect('addon.upload.preview', identifier)
+
+    return render_to_response(template_name, {'form': form},
+                              context_instance=RequestContext(request))
+
+
+@superuser_required
+def addon_upload_preview(request, sid, template_name="base/addon_upload_preview.html"):
+
+    if not sid in request.session:
+        raise Http404
+    path = request.session[sid]
+
+    addon_zip = zipfile.ZipFile(default_storage.open(path))
+    addon_name = addon_zip.namelist()[0]
+    addon_name = addon_name.strip('/')
+    if not os.path.isdir(os.path.join(settings.SITE_ADDONS_PATH, addon_name)):
+        subprocess.Popen(["python", "manage.py",
+                          "upload_addon",
+                          '--zip_path=%s' % path])
+        return redirect('addon.upload.process', sid)
+
+    if request.method == "POST":
+        shutil.rmtree(os.path.join(settings.SITE_ADDONS_PATH, addon_name))
+        subprocess.Popen(["python", "manage.py",
+                          "upload_addon",
+                          '--zip_path=%s' % path])
+        return redirect('addon.upload.process', sid)
+    
+    return render_to_response(template_name, {'addon_name': addon_name, 'sid':sid },
+                              context_instance=RequestContext(request))
+
+
+@superuser_required
+def addon_upload_process(request, sid, template_name="base/addon_upload_process.html"):
+
+    if not sid in request.session:
+        raise Http404
+    path = request.session[sid]
+
+    if not default_storage.exists(path):
+        messages.add_message(request, messages.SUCCESS, 'Addon upload complete.')
+        del request.session[sid]
+        return redirect('dashboard')
+
+    return render_to_response(template_name, {'sid': sid },
+                              context_instance=RequestContext(request))
+
+
+def addon_upload_check(request, sid):
+
+    if not sid in request.session:
+        raise Http404
+    path = request.session[sid]
+
+    finished = False
+    if not default_storage.exists(path):
+        finished = True
+
+    return HttpResponse(finished)
